@@ -1,6 +1,10 @@
 from django.contrib import admin
 
-from events.models import Location
+from mittun.events.models import Location, Event
+
+
+class EventAdmin(admin.ModelAdmin):
+    pass
 
 
 class LocationAdmin(admin.ModelAdmin):
@@ -8,3 +12,4 @@ class LocationAdmin(admin.ModelAdmin):
 
 
 admin.site.register(Location, LocationAdmin)
+admin.site.register(Event, EventAdmin)
